@@ -201,14 +201,18 @@ QualifiedIdentifier ContextBuilder::identifierForNode(VariableIdentifierAst* id)
     return QualifiedIdentifier(ret);
 }
 
-IdentifierPair ContextBuilder::identifierPairForNode(IdentifierAst* id )
+IdentifierPair ContextBuilder::identifierPairForNode(IdentifierAst* id, bool isConstIdentifier)
 {
     if (!id) {
         return qMakePair(IndexedString(), QualifiedIdentifier());
     }
     const QString ret = stringForNode(id);
 
-    return qMakePair(IndexedString(ret), QualifiedIdentifier(ret.toLower()));
+    if ( isConstIdentifier ) {
+        return qMakePair(IndexedString(ret), QualifiedIdentifier(ret));
+    } else {
+        return qMakePair(IndexedString(ret), QualifiedIdentifier(ret.toLower()));
+    }
 }
 
 IdentifierPair ContextBuilder::identifierPairForNode(SemiReservedIdentifierAst* id )
@@ -488,6 +492,13 @@ void ContextBuilder::visitUnaryExpression(UnaryExpressionAst* node)
     }
 }
 
+void ContextBuilder::visitFunctionCallParameterListElement(FunctionCallParameterListElementAst* node)
+{
+    DefaultVisitor::visitFunctionCallParameterListElement(node);
+
+    setContextOnNode(node, currentContext());
+}
+
 void ContextBuilder::reportError(const QString& errorMsg, AstNode* node, IProblem::Severity severity)
 {
     reportError(errorMsg, m_editor->findRange(node), severity);
