@@ -19,7 +19,7 @@
 
 #include "declarationnavigationcontext.h"
 
-#include <QtGui/QTextDocument>
+#include <QTextDocument>
 
 #include <klocalizedstring.h>
 
@@ -30,8 +30,8 @@
 #include <language/duchain/types/structuretype.h>
 #include <language/duchain/types/functiontype.h>
 #include <language/duchain/types/integraltype.h>
+#include <language/duchain/types/arraytype.h>
 
-#include "../types/indexedcontainer.h"
 #include "../declarations/classdeclaration.h"
 #include <declarations/classmethoddeclaration.h>
 #include <declarations/traitmethodaliasdeclaration.h>
@@ -194,13 +194,17 @@ void DeclarationNavigationContext::htmlFunction()
         modifyHtml() += QStringLiteral(", ");
       first = false;
 
-      VariableDeclaration *argDec = dynamic_cast<VariableDeclaration*>(decls[currentArgNum]);
+      VariableDeclaration *argDec = nullptr;
+
+      if (!decls.isEmpty()) {
+        argDec = dynamic_cast<VariableDeclaration*>(decls[currentArgNum]);
+      }
 
       if (argDec && argDec->isVariadic()) {
         AbstractType::Ptr variadicType;
-        const auto indexed = argType.cast<IndexedContainer>();
-        if (indexed && indexed->typesCount() == 1) {
-            variadicType = indexed->typeAt(0).abstractType();
+        const auto a_type = argType.cast<KDevelop::ArrayType>();
+        if (a_type) {
+            variadicType = a_type->elementType();
         } else {
             variadicType = AbstractType::Ptr(new IntegralType(IntegralType::TypeMixed));
         }
